==> 0.9.5.tar.gz: lib/src/definitions/localizations.dart <==
import 'label.dart';
import 'section.dart';

class Localizations extends Section {
  Localizations({
    this.name = 'AppLocalizations',
    List<String> supportedLanguageCodes,
    List<Label> labels,
    List<Section> children,
  })  : supportedLanguageCodes = supportedLanguageCodes ?? <String>[],
        super(
            path: [name, 'LabelsData'],
            children: children,
            labels: labels,
            key: null);

  final List<String> supportedLanguageCodes;
  final String name;

  factory Localizations.merge(String name, List<Localizations> values) {
    final result = Localizations(name: name);

    for (var value in values) {
      // Merging supportedLanguageCodes
      result.supportedLanguageCodes.addAll(
        value.supportedLanguageCodes.where(
          (x) => !result.supportedLanguageCodes.contains(x),
        ),
      );

      _mergeSections(result, value);
    }

    return result;
  }

  @override
  List<Object> get props => [
        ...super.props,
        supportedLanguageCodes,
        name,
      ];

  static void _mergeSections(Section result, Section other) {
    // Merging labels
    if (result.labels.isEmpty) {
      result.labels.addAll(other.labels);
    } else {
      for (var otherLabel in other.labels) {
        final existingLabel = result.labels.firstWhere(
          (x) => x.key == otherLabel.key,
          orElse: () => null,
        );
        if (existingLabel == null) {
          result.labels.add(otherLabel);
        } else {
          for (var otherCase in otherLabel.cases) {
            final existingCase = existingLabel.cases.firstWhere(
              (x) => x.condition == otherCase.condition,
              orElse: () => null,
            );
            if (existingCase == null) {
              existingLabel.cases.add(otherCase);
            } else {
              existingCase.translations.addAll(otherCase.translations);
            }
          }
        }
      }
    }

    // Merging children
    if (result.children.isEmpty) {
      result.children.addAll(other.children);
    } else {
      for (var otherChild in other.children) {
        final existingChild = result.children.firstWhere(
          (x) => x.key == otherChild.key,
          orElse: () => null,
        );
        if (existingChild == null) {
          result.children.add(otherChild);
        } else {
          _mergeSections(existingChild, otherChild);
        }
      }
    }
  }

  Localizations copyWith({
    List<String> supportedLanguageCodes,
    List<Label> labels,
    List<Section> children,
    String name,
  }) {
    return Localizations(
      supportedLanguageCodes:
          supportedLanguageCodes ?? this.supportedLanguageCodes,
      labels: labels ?? this.labels,
      children: children ?? this.children,
      name: name ?? this.name,
    );
  }
}

==> 0.9.7.tar.gz: lib/src/definitions/localizations.dart <==
import 'label.dart';
import 'section.dart';

class Localizations extends Section {
  Localizations({
    this.name = 'AppLocalizations',
    List<String> supportedLanguageCodes,
    List<Label> labels,
    List<Section> children,
  })  : supportedLanguageCodes = supportedLanguageCodes ?? <String>[],
        super(
            path: [name ?? 'AppLocalizations', 'LabelsData'],
            children: children,
            labels: labels,
            key: null);

  final List<String> supportedLanguageCodes;
  final String name;

  factory Localizations.merge(String name, List<Localizations> values) {
    final result = Localizations(name: name);

    for (var value in values) {
      // Merging supportedLanguageCodes
      result.supportedLanguageCodes.addAll(
        value.supportedLanguageCodes.where(
          (x) => !result.supportedLanguageCodes.contains(x),
        ),
      );

      _mergeSections(result, value);
    }

    return result;
  }

  @override
  List<Object> get props => [
        ...super.props,
        supportedLanguageCodes,
        name,
      ];

  static void _mergeSections(Section result, Section other) {
    // Merging labels
    if (result.labels.isEmpty) {
      result.labels.addAll(other.labels);
    } else {
      for (var otherLabel in other.labels) {
        final existingLabel = result.labels.firstWhere(
          (x) => x.key == otherLabel.key,
          orElse: () => null,
        );
        if (existingLabel == null) {
          result.labels.add(otherLabel);
        } else {
          for (var otherCase in otherLabel.cases) {
            final existingCase = existingLabel.cases.firstWhere(
              (x) => x.condition == otherCase.condition,
              orElse: () => null,
            );
            if (existingCase == null) {
              existingLabel.cases.add(otherCase);
            } else {
              existingCase.translations.addAll(otherCase.translations);
            }
          }
        }
      }
    }

    // Merging children
    if (result.children.isEmpty) {
      result.children.addAll(other.children);
    } else {
      for (var otherChild in other.children) {
        final existingChild = result.children.firstWhere(
          (x) => x.key == otherChild.key,
          orElse: () => null,
        );
        if (existingChild == null) {
          result.children.add(otherChild);
        } else {
          _mergeSections(existingChild, otherChild);
        }
      }
    }
  }

  Localizations copyWith({
    List<String> supportedLanguageCodes,
    List<Label> labels,
    List<Section> children,
    String name,
  }) {
    return Localizations(
      supportedLanguageCodes:
          supportedLanguageCodes ?? this.supportedLanguageCodes,
      labels: labels ?? this.labels,
      children: children ?? this.children,
      name: name ?? this.name,
    );
  }
}
